@@ -1,8 +1,6 @@
-Index: b/setup.py
-===================================================================
 --- a/setup.py
 +++ b/setup.py
-@@ -21,12 +21,15 @@ from distutils.command.build_ext import
+@@ -20,12 +20,15 @@ from distutils.command.build_ext import
  
  from setuptools import Extension, setup
  
@@ -19,8 +17,26 @@ Index: b/setup.py
      warnings.warn(
          "Pillow does not yet support Python {}.{} and does not yet provide "
          "prebuilt Windows binaries. We do not recommend building from "
-@@ -218,6 +221,38 @@ class pil_build_ext(build_ext):
-                 _dbg('Requiring %s', x)
+@@ -131,7 +134,7 @@ def _dbg(s, tp=None):
+ def _find_library_dirs_ldconfig():
+     # Based on ctypes.util from Python 2
+ 
+-    if sys.platform.startswith("linux") or sys.platform.startswith("gnu"):
++    if host_platform.startswith("linux") or host_platform.startswith("gnu"):
+         if struct.calcsize("l") == 4:
+             machine = os.uname()[4] + "-32"
+         else:
+@@ -153,7 +156,7 @@ def _find_library_dirs_ldconfig():
+         env["LC_ALL"] = "C"
+         env["LANG"] = "C"
+ 
+-    elif sys.platform.startswith("freebsd"):
++    elif host_platform.startswith("freebsd"):
+         args = ["/sbin/ldconfig", "-r"]
+         expr = r".* => (.*)"
+         env = {}
+@@ -340,6 +343,38 @@ class pil_build_ext(build_ext):
+                 _dbg("Requiring %s", x)
                  self.feature.required.add(x)
  
 +    def add_gcc_paths(self):
@@ -58,43 +74,44 @@ Index: b/setup.py
      def build_extensions(self):
  
          library_dirs = []
-@@ -289,13 +324,13 @@ class pil_build_ext(build_ext):
+@@ -417,14 +452,14 @@ class pil_build_ext(build_ext):
          if self.disable_platform_guessing:
              pass
  
 -        elif sys.platform == "cygwin":
 +        elif host_platform == "cygwin":
              # pythonX.Y.dll.a is in the /usr/lib/pythonX.Y/config directory
-             _add_directory(library_dirs,
-                            os.path.join("/usr/lib", "python%s" %
-                                         sys.version[:3], "config"))
+             _add_directory(
+                 library_dirs,
+                 os.path.join("/usr/lib", "python%s" % sys.version[:3], "config"),
+             )
  
 -        elif sys.platform == "darwin":
 +        elif host_platform == "darwin":
              # attempt to make sure we pick freetype2 over other versions
              _add_directory(include_dirs, "/sw/include/freetype2")
              _add_directory(include_dirs, "/sw/lib/freetype2/include")
-@@ -333,7 +368,7 @@ class pil_build_ext(build_ext):
-                 _add_directory(library_dirs, "/usr/X11/lib")
+@@ -465,13 +500,13 @@ class pil_build_ext(build_ext):
                  _add_directory(include_dirs, "/usr/X11/include")
  
--        elif sys.platform.startswith("linux"):
-+        elif host_platform.startswith("linux"):
-             arch_tp = (plat.processor(), plat.architecture()[0])
-             # This should be correct on debian derivatives.
-             if os.path.exists('/etc/debian_version'):
-@@ -389,18 +424,18 @@ class pil_build_ext(build_ext):
-                                    os.path.join(os.environ['ANDROID_ROOT'],
-                                                 'lib'))
- 
--        elif sys.platform.startswith("gnu"):
-+        elif host_platform.startswith("gnu"):
-             self.add_multiarch_paths()
- 
--        elif sys.platform.startswith("freebsd"):
-+        elif host_platform.startswith("freebsd"):
-             _add_directory(library_dirs, "/usr/local/lib")
-             _add_directory(include_dirs, "/usr/local/include")
+         elif (
+-            sys.platform.startswith("linux")
+-            or sys.platform.startswith("gnu")
+-            or sys.platform.startswith("freebsd")
++            host_platform.startswith("linux")
++            or host_platform.startswith("gnu")
++            or host_platform.startswith("freebsd")
+         ):
+             for dirname in _find_library_dirs_ldconfig():
+                 _add_directory(library_dirs, dirname)
+-            if sys.platform.startswith("linux") and os.environ.get(
++            if host_platform.startswith("linux") and os.environ.get(
+                 "ANDROID_ROOT", None
+             ):
+                 # termux support for android.
+@@ -482,11 +517,11 @@ class pil_build_ext(build_ext):
+                     library_dirs, os.path.join(os.environ["ANDROID_ROOT"], "lib")
+                 )
  
 -        elif sys.platform.startswith("netbsd"):
 +        elif host_platform.startswith("netbsd"):
@@ -106,46 +123,43 @@ Index: b/setup.py
              _add_directory(library_dirs, "/opt/local/lib")
              _add_directory(include_dirs, "/opt/local/include")
  
-@@ -418,7 +453,7 @@ class pil_build_ext(build_ext):
+@@ -502,7 +537,7 @@ class pil_build_ext(build_ext):
+             # alpine, at least
+             _add_directory(library_dirs, "/lib")
  
-         # on Windows, look for the OpenJPEG libraries in the location that
-         # the official installer puts them
 -        if sys.platform == "win32":
 +        if host_platform == "win32":
-             program_files = os.environ.get('ProgramFiles', '')
-             best_version = (0, 0)
-             best_path = None
-@@ -452,7 +487,7 @@ class pil_build_ext(build_ext):
+             if PLATFORM_MINGW:
+                 _add_directory(
+                     include_dirs, "C:\\msys64\\mingw32\\include\\libimagequant"
+@@ -542,7 +577,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "zlib.h"):
                  if _find_library_file(self, "z"):
                      feature.zlib = "z"
--                elif (sys.platform == "win32" and
-+                elif (host_platform == "win32" and
-                       _find_library_file(self, "zlib")):
+-                elif sys.platform == "win32" and _find_library_file(self, "zlib"):
++                elif host_platform == "win32" and _find_library_file(self, "zlib"):
                      feature.zlib = "zlib"  # alternative name
  
-@@ -461,7 +496,7 @@ class pil_build_ext(build_ext):
+         if feature.want("jpeg"):
+@@ -550,7 +585,7 @@ class pil_build_ext(build_ext):
              if _find_include_file(self, "jpeglib.h"):
                  if _find_library_file(self, "jpeg"):
                      feature.jpeg = "jpeg"
--                elif (sys.platform == "win32" and
-+                elif (host_platform == "win32" and
-                       _find_library_file(self, "libjpeg")):
+-                elif sys.platform == "win32" and _find_library_file(self, "libjpeg"):
++                elif host_platform == "win32" and _find_library_file(self, "libjpeg"):
                      feature.jpeg = "libjpeg"  # alternative name
  
-@@ -516,9 +551,9 @@ class pil_build_ext(build_ext):
-             if _find_include_file(self, 'tiff.h'):
+         feature.openjpeg_version = None
+@@ -606,7 +641,7 @@ class pil_build_ext(build_ext):
+             if _find_include_file(self, "tiff.h"):
                  if _find_library_file(self, "tiff"):
                      feature.tiff = "tiff"
--                if sys.platform == "win32" and _find_library_file(self, "libtiff"):
-+                if host_platform == "win32" and _find_library_file(self, "libtiff"):
+-                if sys.platform in ["win32", "darwin"] and _find_library_file(
++                if host_platform in ["win32", "darwin"] and _find_library_file(
+                     self, "libtiff"
+                 ):
                      feature.tiff = "libtiff"
--                if (sys.platform == "darwin" and
-+                if (host_platform == "darwin" and
-                         _find_library_file(self, "libtiff")):
-                     feature.tiff = "libtiff"
- 
-@@ -599,7 +634,7 @@ class pil_build_ext(build_ext):
+@@ -691,7 +726,7 @@ class pil_build_ext(build_ext):
          if feature.jpeg2000:
              libs.append(feature.jpeg2000)
              defs.append(("HAVE_OPENJPEG", None))
@@ -154,14 +168,14 @@ Index: b/setup.py
                  defs.append(("OPJ_STATIC", None))
          if feature.zlib:
              libs.append(feature.zlib)
-@@ -610,12 +645,12 @@ class pil_build_ext(build_ext):
+@@ -702,12 +737,12 @@ class pil_build_ext(build_ext):
          if feature.tiff:
              libs.append(feature.tiff)
              defs.append(("HAVE_LIBTIFF", None))
 -        if sys.platform == "win32":
 +        if host_platform == "win32":
              libs.extend(["kernel32", "user32", "gdi32"])
-         if struct.unpack("h", "\0\1".encode('ascii'))[0] == 1:
+         if struct.unpack("h", "\0\1".encode("ascii"))[0] == 1:
              defs.append(("WORDS_BIGENDIAN", None))
  
 -        if sys.platform == "win32" and not (PLATFORM_PYPY or PLATFORM_MINGW):
@@ -169,25 +183,25 @@ Index: b/setup.py
              defs.append(("PILLOW_VERSION", '"\\"%s\\""' % PILLOW_VERSION))
          else:
              defs.append(("PILLOW_VERSION", '"%s"' % PILLOW_VERSION))
-@@ -637,7 +672,7 @@ class pil_build_ext(build_ext):
+@@ -731,7 +766,7 @@ class pil_build_ext(build_ext):
  
          if feature.lcms:
              extra = []
 -            if sys.platform == "win32":
 +            if host_platform == "win32":
                  extra.extend(["user32", "gdi32"])
-             exts.append(Extension("PIL._imagingcms",
-                                   ["src/_imagingcms.c"],
-@@ -657,7 +692,7 @@ class pil_build_ext(build_ext):
-                                   libraries=libs,
-                                   define_macros=defs))
+             exts.append(
+                 Extension(
+@@ -756,7 +791,7 @@ class pil_build_ext(build_ext):
+                 )
+             )
  
--        tk_libs = ['psapi'] if sys.platform == 'win32' else []
-+        tk_libs = ['psapi'] if host_platform == 'win32' else []
-         exts.append(Extension("PIL._imagingtk",
-                               ["src/_imagingtk.c", "src/Tk/tkImaging.c"],
-                               include_dirs=['src/Tk'],
-@@ -682,7 +717,7 @@ class pil_build_ext(build_ext):
+-        tk_libs = ["psapi"] if sys.platform == "win32" else []
++        tk_libs = ["psapi"] if host_platform == "win32" else []
+         exts.append(
+             Extension(
+                 "PIL._imagingtk",
+@@ -785,7 +820,7 @@ class pil_build_ext(build_ext):
          print("-" * 68)
          print("version      Pillow %s" % PILLOW_VERSION)
          v = sys.version.split("[")
